@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this
-#repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
 from .location import *
@@ -7,15 +7,18 @@ from .shipment import *
 from .period import *
 from .move import *
 from .product import *
-from .inventory import *
+from . import inventory
 from .configuration import *
+from . import party
 
 
 def register():
     Pool.register(
         Location,
         Party,
-        ProductsByLocationsStart,
+        PartyLocation,
+        ProductsByLocationsContext,
+        LocationLeadTime,
         Move,
         ShipmentIn,
         ShipmentInReturn,
@@ -30,21 +33,25 @@ def register():
         Cache,
         Template,
         Product,
-        ProductByLocationStart,
+        ProductByLocationContext,
         ProductQuantitiesByWarehouse,
-        ProductQuantitiesByWarehouseStart,
-        Inventory,
-        InventoryLine,
+        ProductQuantitiesByWarehouseContext,
+        inventory.Inventory,
+        inventory.InventoryLine,
+        inventory.CountSearch,
+        inventory.CountQuantity,
         Configuration,
+        ConfigurationSequence,
+        ConfigurationLocation,
         module='stock', type_='model')
     Pool.register(
-        ProductsByLocations,
         AssignShipmentOut,
         AssignShipmentInternal,
         AssignShipmentInReturn,
-        CreateShipmentOutReturn,
-        ProductByLocation,
-        OpenProductQuantitiesByWarehouse,
+        RecomputeCostPrice,
+        inventory.Count,
+        party.PartyReplace,
+        party.PartyErase,
         module='stock', type_='wizard')
     Pool.register(
         DeliveryNote,
